configurationtools.AbjadConfig
==============================

.. abjad-lineage:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig

.. autoclass:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.ABJAD_CONFIG_DIRECTORY_PATH
   :noindex:

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.ABJAD_CONFIG_FILE_PATH
   :noindex:

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.ABJAD_EXPERIMENTAL_PATH
   :noindex:

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.ABJAD_OUTPUT_PATH
   :noindex:

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.ABJAD_PATH
   :noindex:

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.ABJAD_ROOT_PATH
   :noindex:

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.HOME_PATH
   :noindex:

.. autoattribute:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.clear
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.get
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.get_config_spec
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.get_initial_comment
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.get_option_comments
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.get_option_definitions
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.get_option_specs
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.items
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.iteritems
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.iterkeys
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.itervalues
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.keys
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.pop
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.popitem
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.setdefault
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.update
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.values
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__contains__
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__delitem__
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__eq__
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__ge__
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__getitem__
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__gt__
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__iter__
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__le__
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__len__
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__lt__
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__ne__
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__repr__
   :noindex:

.. automethod:: abjad.tools.configurationtools.AbjadConfig.AbjadConfig.AbjadConfig.__setitem__
   :noindex:
